from django.urls import path
from django.contrib.auth import views as auth_views
from . import views

app_name = 'users'
urlpatterns = [
    path(
        'new',
        views.create_user,
        name='new-user'
    ),
    path(
        'login',
        auth_views.LoginView.as_view(template_name="edit.html"),
        name='login'
    ),
    path(
        'logout',
        auth_views.LogoutView.as_view(),
        name='logout'
    ),
    path(
        'password_change',
        auth_views.PasswordChangeView.as_view(template_name="edit.html"),
        name='password-change'
    ),
    path(
        'password_change/done',
        auth_views.PasswordChangeDoneView.as_view(template_name="base.html"),
        name='password-change-done'
    ),
    path(
        'reset/<uidb64>/<token>/',
        auth_views.PasswordResetConfirmView.as_view(template_name="edit.html"),
        name='password-reset-confirm'
    ),
    path(
        'reset/done/',
        auth_views.PasswordResetCompleteView.as_view(template_name="base.html"),
        name='password-reset-done'
    ),
    path(
        'school/new',
        views.create_school,
        name='new-school'
    ),
    path(
        'school/<int:pk>',
        views.school,
        name='school',
    ),
    path(
        'school/<int:pk>/edit_phone',
        views.edit_phone,
        name='edit-school-phone'
    ),
    path(
        'school/<int:pk>/edit_name',
        views.edit_name,
        name='edit-school-name'
    ),
    path(
        'school/<int:pk>/edit_mail',
        views.edit_mail,
        name='edit-school-mail'
    ),
    path(
        'school/<int:pk>/jury_1',
        views.edit_jury_1,
        name='edit-jury-1'
    ),
    path(
        'school/<int:pk>/jury_2',
        views.edit_jury_2,
        name='edit-jury-2'
    ),
    path(
        'school/<int:pk>/edit_admin',
        views.edit_admin,
        name='edit-admin'
    ),
    path(
        'school/<int:pk>/validate',
        views.validate,
        name='validate',
    )
]
